summaryrefslogtreecommitdiffstats
path: root/raul/Namespaces.h
diff options
context:
space:
mode:
Diffstat (limited to 'raul/Namespaces.h')
-rw-r--r--raul/Namespaces.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/raul/Namespaces.h b/raul/Namespaces.h
index d28089f..1de95f8 100644
--- a/raul/Namespaces.h
+++ b/raul/Namespaces.h
@@ -1,11 +1,11 @@
-/* This file is part of Ingen. Copyright (C) 2006 Dave Robillard.
+/* This file is part of Raul. Copyright (C) 2007 Dave Robillard.
*
* Ingen is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.
*
@@ -20,6 +20,8 @@
#include <map>
#include <string>
+namespace Raul {
+
/** Collection of RDF namespaces with prefixes.
*/
@@ -29,4 +31,6 @@ public:
};
+} // namespace Raul
+
#endif // RAUL_NAMESPACES_H
@@ -1,11 +1,11 @@
*
- * Ingen is free software; you can redistribute it and/or modify it under the
+ * Raul is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
@@ -1,11 +1,11 @@
* version.
*
- * Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Raul is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.